@@ -8,12 +8,12 @@ app.add_typer(users_app, name="users")
 
 @users_app.callback()
 def users_callback():
-    typer.echo("Running a users command")
+    print("Running a users command")
 
 
 @users_app.command()
 def create(name: str):
-    typer.echo(f"Creating user: {name}")
+    print(f"Creating user: {name}")
 
 
 if __name__ == "__main__":
