@@ -23,7 +23,7 @@ def test_no_path(tmpdir):
 
 def test_not_exists(tmpdir):
     config_file = Path(tmpdir) / "config.txt"
-    if config_file.exists():  # pragma no cover
+    if config_file.exists():  # pragma: no cover
         config_file.unlink()
     result = runner.invoke(app, ["--config", f"{config_file}"])
     assert result.exit_code == 0
@@ -48,8 +48,7 @@ def test_dir():
 def test_script():
     result = subprocess.run(
         [sys.executable, "-m", "coverage", "run", mod.__file__, "--help"],
-        stdout=subprocess.PIPE,
-        stderr=subprocess.PIPE,
+        capture_output=True,
         encoding="utf-8",
     )
     assert "Usage" in result.stdout
